# ngshare
[nbgrader](https://github.com/jupyter/nbgrader) sharing service.

<img src="ngshare/favicon.png" width="64px" />

[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)
[![Build Status](https://travis-ci.org/lxylxy123456/ngshare.svg?branch=master)](https://travis-ci.org/lxylxy123456/ngshare)
[![codecov](https://codecov.io/gh/lxylxy123456/ngshare/branch/master/graph/badge.svg)](https://codecov.io/gh/lxylxy123456/ngshare)
[![Documentation Status](https://readthedocs.org/projects/ngshare/badge/?version=latest)](https://ngshare.readthedocs.io/en/latest/?badge=latest)

## What can I use it for?
You can use ngshare if you
* Need to run nbgrader on a distributed set up (such as Zero to JupyterHub, using DockerSpawner, etc)
* Need better course management without messing with filesystem permissions and user groups

## Documentation
The API specifications, installation guide, and documentation for `ngshare` are
 in [Read the Docs](https://ngshare.readthedocs.io/en/latest/).

## Youtube Video Demo
http://www.youtube.com/watch?v=SEJCaqD7xXQ

[![Youtube Video Demo](http://img.youtube.com/vi/SEJCaqD7xXQ/0.jpg)](http://www.youtube.com/watch?v=SEJCaqD7xXQ)

